@@ -37,7 +37,16 @@ kickoff.writeConfig("showAppsByName", "true")
 panel.addWidget("org.kde.plasma.pager")
 
 var taskmanager = panel.addWidget("org.kde.plasma.icontasks")
-var launcherlist = [ ]
+var launcherlist = [ "preferred://browser",
+                     "applications:com.github.ovenwerks.studio-controls.desktop",
+                     "applications:ardour.desktop",
+                     "applications:com.obsproject.Studio.desktop",
+                     "applications:org.kde.krita.desktop",
+                     "applications:gimp.desktop",
+                     "applications:org.kde.kdenlive.desktop",
+                     "applications:org.kde.digikam.desktop",
+                     "applications:darktable.desktop",
+                     "applications:systemsettings.desktop" ]
 taskmanager.writeConfig("launchers", launcherlist)
 
 /* Next up is determining whether to add the Input Method Panel
